@@ -1,7 +1,6 @@
 #include "test.h"
-#include <panda/CallbackDispatcher.h>
 #include <panda/function_utils.h>
-#include <panda/lib/from_chars.h>
+#include <panda/CallbackDispatcher.h>
 
 using panda::CallbackDispatcher;
 using test::Tracer;
@@ -140,7 +139,7 @@ TEST_CASE("remove callback comparable functor" , "[callbackdispatcher]") {
         }
     };
 
-    static_assert(panda::lib::traits::has_call_operator<S, int>::value,
+    static_assert(panda::has_call_operator<S, int>::value,
                   "S shuld be callable, it can be wrong implementation of panda::has_call_operator or a compiler error");
 
     S src;
@@ -179,7 +178,7 @@ TEST_CASE("remove callback comparable full functor" , "[callbackdispatcher]") {
         }
     };
 
-    static_assert(panda::lib::traits::has_call_operator<S,Dispatcher::Event&, int>::value,
+    static_assert(panda::has_call_operator<S,Dispatcher::Event&, int>::value,
                   "S shuld be callable, it can be wrong implementation of panda::has_call_operator or a compiler error");
 
     S src;
@@ -293,3 +292,28 @@ TEST_CASE("dispatcher const ref arg move" , "[callbackdispatcher]") {
     S s;
     s.call();
 }
+
+TEST_CASE("dispatcher lambda self reference auto...", "[callbackdispatcher]") {
+    CallbackDispatcher<void(int)> d1;
+    CallbackDispatcher<int(int)>  d2;
+
+    auto l1 = [](auto...args) -> void { static_assert(sizeof...(args) == 1, "auto... resolved as without SELF"); };
+    auto l2 = [](auto&&...args) -> void { static_assert(sizeof...(args) == 1, "auto... resolved as without SELF"); };
+    auto l3 = [](auto&&...args) { REQUIRE(sizeof...(args) == 1); };
+
+    d1.add(l1);
+    d1.add(l2);
+    d1.add(l3);
+    d2.add(l1);
+    d2.add(l2);
+    d2.add(l3);
+
+    auto l1a = [](auto&, auto...args) -> int { static_assert(sizeof...(args) == 1, "auto... resolved as without SELF"); return 1; };
+    auto l2a = [](auto&&...args) -> int { static_assert(sizeof...(args) == 2, "auto... resolved as without SELF"); return 2; };
+    auto l3a = [](auto&&...args) { REQUIRE(sizeof...(args) == 2); return 3; };
+
+    d2.add_event_listener(l1a);
+    d2.add_event_listener(l2a);
+    d2.add_event_listener(l3a);
+}
+
